netapp_ontap.models.application_statistics_components_space API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.application_statistics_components_space`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ApplicationStatisticsComponentsSpaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ApplicationStatisticsComponentsSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available: Size GET`

    The available amount of space left in the application component. Note that this field has limited meaning for SAN applications. Space may be considered used from ONTAP's perspective while the host filesystem still considers it available.

  `logical_used: Size GET`

    The amount of space that would currently be used if no space saving features were enabled. For example, if compression were the only space saving feature enabled, this field would represent the uncompressed amount of space used.

  `provisioned: Size GET`

    The originally requested amount of space that was provisioned for the application component.

  `reserved_unused: Size GET`

    The amount of space reserved for system features such as Snapshot copies that has not yet been used.

  `savings: Size GET`

    The amount of space saved by all enabled space saving features.

  `used: Size GET`

    The amount of space that is currently being used by the application component. Note that this includes any space reserved by the system for features such as Snapshot copies.

  `used_excluding_reserves: Size GET`

    The amount of space that is currently being used, excluding any space that is reserved by the system for features such as Snapshot copies.

  `used_percent: Size GET`

    The percentage of the originally provisioned space that is currently being used by the application component.